import pytest
from rq_interfaces.srv import AquireProjection, ReachabilityCheck, ReachabilityMapCheck
from rq_controller.common import PyProjection, PyVolume
from rq_hardware.hardware_client import HardwareClient


@pytest.fixture
def hardware_client_node():
    return HardwareClient


def test_projection_response_2_py(hardware_client_node):
    response = AquireProjection.Response()
    response.projection = PyProjection.dummy().as_message()

    result = hardware_client_node.projection_response_2_py(response)

    assert isinstance(result, PyProjection)


def test_reachability_response_2_py(hardware_client_node):
    response = ReachabilityCheck.Response()
    response.checked_scan_pose.reachable = True
    response.checked_scan_pose.cost = 1.0
    response.checked_scan_pose.scan_pose = PyProjection.dummy().as_message()

    result = hardware_client_node.reachability_response_2_py(response)

    assert isinstance(result, tuple)
    assert result[0]
    assert result[1] == 1.0
    assert isinstance(result[2], PyProjection)


def test_reachability_map_response_2_py(hardware_client_node):
    response = ReachabilityMapCheck.Response()
    response.ocupation_map = PyVolume.dummy().as_message()

    result = hardware_client_node.reachability_map_response_2_py(response)

    assert isinstance(result, PyVolume)
